
/**
* Computes a Hash-based Message Authentication Code (HMAC) using the SHA1 hash function.
*/
fun HMACBinary(content: Binary, secret: Binary): Binary = native("system::crypto_hmac")

/**
* Computes the hash of the specified content with the given algorithm and return the binary content
*
* Algorithm can be "SHA-1", "MD5", "SHA-256", etc
*
*/
fun hashWith(content: Binary, algorithm: String = "SHA-1"): Binary = native("system::crypto_hash")

/**
* Computes the HMAC hash and transforms and transforms the  binary result inta a hexadecimal lower case string.
*/
fun HMACWith(content: Binary, secret: Binary): String =
  lower(
    dw::core::Binary::toHex(
      HMACBinary(content, secret)
    )
  )

/**
* Computes the MD5 hash and transforms and transforms the  binary result inta a hexadecimal lower case string.
*
* .Transform
* ----
* %dw 2.0
* output application/json
* ---
* Crypto::MD5("asd")
* ----
*
* .Output
* ----
* "7815696ecbf1c96e6894b779456d330e"
* ----
*/
fun MD5(content: Binary): String =
  lower(
    dw::core::Binary::toHex(content hashWith "MD5")
   )

/**
* Computes the MD5 hash and transforms and transforms the  binary result inta a hexadecimal lower case string.
*
* .Transform
* ----
* %dw 2.0
* output application/json
* ---
* Crypto::SHA1("dsasd"),
* ----
*
* .Output
* ----
* "2fa183839c954e6366c206367c9be5864e4f4a65",
* ----
*/
fun SHA1(content: Binary): String =
  lower(
    dw::core::Binary::toHex(
      content hashWith "SHA1"
    )
   )